.. Copyright (C) 2015-2017 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2016-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _debops-contrib.foodsoft:

Ansible role: debops-contrib.foodsoft
=====================================

.. toctree::
   :maxdepth: 2

   introduction
   getting-started
   defaults
   copyright
   changelog

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
